@@ -20,7 +20,7 @@
 
 import Cairo from 'gi://cairo';
 import Clutter from 'gi://Clutter';
-import Gio from 'gi://Gio';
+import Cogl from 'gi://Cogl';
 import GLib from 'gi://GLib';
 import GObject from 'gi://GObject';
 import Pango from 'gi://Pango';
@@ -90,25 +90,9 @@ const IndicatorMenu = class extends PopupMenu.PopupMenu {
         return this._indicator;
     }
 
-    // TODO: move to utils
-    _loadIcon(iconName) {
-        let icon = this._icons[iconName];
-
-        if (!icon) {
-            const iconUri = '%s/icons/hicolor/scalable/actions/%s.svg'.format(extension.dir.get_uri(), iconName);
-            icon = new Gio.FileIcon({
-                file: Gio.File.new_for_uri(iconUri),
-            });
-
-            this._icons[iconName] = icon;
-        }
-
-        return icon;
-    }
-
     _createIconButton(iconName, accessibleName) {
         const icon = new St.Icon({
-            gicon: this._loadIcon(iconName),
+            gicon: Utils.loadIcon(iconName),
             style_class: 'popup-menu-icon',
         });
         const iconButton = new St.Button({
@@ -217,16 +201,16 @@ const IndicatorMenu = class extends PopupMenu.PopupMenu {
         this._timerButton.can_focus = this._timerButton.reactive;
 
         if (!this._isPaused) {
-            this._pauseResumeButton.child.gicon = this._loadIcon('gnome-pomodoro-pause-symbolic');
+            this._pauseResumeButton.child.gicon = Utils.loadIcon('gnome-pomodoro-pause-symbolic');
             this._pauseResumeButton.accessible_name = isBreak ? _('Pause break') : _('Pause Pomodoro');
 
-            this._skipStopButton.child.gicon = this._loadIcon('gnome-pomodoro-skip-symbolic');
+            this._skipStopButton.child.gicon = Utils.loadIcon('gnome-pomodoro-skip-symbolic');
             this._skipStopButton.accessible_name = isBreak ? _('Start Pomodoro') : _('Take a break');
         } else {
-            this._pauseResumeButton.child.gicon = this._loadIcon('gnome-pomodoro-start-symbolic');
+            this._pauseResumeButton.child.gicon = Utils.loadIcon('gnome-pomodoro-start-symbolic');
             this._pauseResumeButton.accessible_name = isBreak ? _('Resume break') : _('Resume Pomodoro');
 
-            this._skipStopButton.child.gicon = this._loadIcon('gnome-pomodoro-stop-symbolic');
+            this._skipStopButton.child.gicon = Utils.loadIcon('gnome-pomodoro-stop-symbolic');
             this._skipStopButton.accessible_name = _('Stop');
         }
     }
@@ -285,7 +269,7 @@ const IndicatorMenu = class extends PopupMenu.PopupMenu {
         this.itemActivated(PopupAnimation.NONE);
 
         if (notificationManager)
-            notificationManager.openDialog();
+            notificationManager.openScreenOverlay();
     }
 
     _onStartClicked() {
@@ -676,12 +660,21 @@ const IconIndicator = class extends EventEmitter {
         const themeNode = actor.get_theme_node();
         const color = themeNode.get_foreground_color();
         this._primaryColor = color;
-        this._secondaryColor = new Clutter.Color({
-            red: color.red,
-            green: color.green,
-            blue: color.blue,
-            alpha: color.alpha * FADE_OUT_OPACITY,
-        });
+
+        if (Utils.isVersionAtLeast('47'))
+            this._secondaryColor = new Cogl.Color({
+                red: color.red,
+                green: color.green,
+                blue: color.blue,
+                alpha: color.alpha * FADE_OUT_OPACITY,
+            });
+        else
+            this._secondaryColor = new Clutter.Color({
+                red: color.red,
+                green: color.green,
+                blue: color.blue,
+                alpha: color.alpha * FADE_OUT_OPACITY,
+            });
     }
 
 
